# thousandeyes-sdk-credentials
Manage credentials for transaction tests using the Credentials API.

The following permissions are required to access Credentials API operations:

* `Settings Tests Read` for read operations.
* `Settings Tests Update` for write operations.
* `View sensitive data in web transaction scripts` to view the encrypted value property of credentials.
* `Settings Tests Create Transaction (Tx) Tests` to create credentials.

For more information about credentials, see [Working With Secure Credentials](https://docs.thousandeyes.com/product-documentation/browser-synthetics/transaction-tests/getting-started/working-with-secure-credentials).


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 7.0.36
- Generator version: 7.6.0
- Build package: com.thousandeyes.api.codegen.ThousandeyesPythonGenerator

## Requirements.

Python 3.8+

## Installation & Usage
### pip install

Install directly via PyPi:

```sh
pip install thousandeyes-sdk-credentials
```
(you may need to run `pip` with root permission: `sudo pip install thousandeyes-sdk-credentials`)

Then import the package:
```python
import thousandeyes_sdk.credentials
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import thousandeyes_sdk.credentials
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the installation procedure and then run the following:

```python

import thousandeyes_sdk.core
import thousandeyes_sdk.credentials
from thousandeyes_sdk.core.exceptions import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://api.thousandeyes.com/v7
# See configuration.py for a list of all supported configuration parameters.
configuration = thousandeyes_sdk.core.Configuration(
    host = "https://api.thousandeyes.com/v7"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: BearerAuth
configuration = thousandeyes_sdk.core.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with thousandeyes_sdk.core.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = thousandeyes_sdk.credentials.CredentialsApi(api_client)
    credential_request = thousandeyes_sdk.credentials.CredentialRequest() # CredentialRequest | 
    aid = '1234' # str | A unique identifier associated with your account group. You can retrieve your `AccountGroupId` from the `/account-groups` endpoint. Note that you must be assigned to the target account group. Specifying this parameter without being assigned to the target account group will result in an error response. (optional)

    try:
        # Create credential
        api_response = api_instance.create_credential(credential_request, aid=aid)
        print("The response of CredentialsApi->create_credential:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling CredentialsApi->create_credential: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.thousandeyes.com/v7*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CredentialsApi* | [**create_credential**](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-credentials/docs/CredentialsApi.md#create_credential) | **POST** /credentials | Create credential
*CredentialsApi* | [**delete_credential**](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-credentials/docs/CredentialsApi.md#delete_credential) | **DELETE** /credentials/{id} | Delete credential
*CredentialsApi* | [**get_credential**](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-credentials/docs/CredentialsApi.md#get_credential) | **GET** /credentials/{id} | Retrieve credential
*CredentialsApi* | [**get_credentials**](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-credentials/docs/CredentialsApi.md#get_credentials) | **GET** /credentials | List credentials
*CredentialsApi* | [**update_credential**](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-credentials/docs/CredentialsApi.md#update_credential) | **PUT** /credentials/{id} | Update credential


## Documentation For Models

 - [Credential](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-credentials/docs/Credential.md)
 - [CredentialRequest](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-credentials/docs/CredentialRequest.md)
 - [CredentialWithoutValue](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-credentials/docs/CredentialWithoutValue.md)
 - [Credentials](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-credentials/docs/Credentials.md)
 - [Error](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-credentials/docs/Error.md)
 - [Link](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-credentials/docs/Link.md)
 - [SelfLinks](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-credentials/docs/SelfLinks.md)
 - [UnauthorizedError](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-credentials/docs/UnauthorizedError.md)
 - [ValidationError](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-credentials/docs/ValidationError.md)
 - [ValidationErrorItem](https://github.com/thousandeyes/thousandeyes-sdk-python//tree/main/thousandeyes-sdk-credentials/docs/ValidationErrorItem.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="BearerAuth"></a>
### BearerAuth

- **Type**: Bearer authentication


## Author

<a href="mailto:api-team@thousandeyes.com">ThousandEyes API Team </a>


